package Acme::MetaSyntactic::crypto;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::crypto - The crypto theme

=head1 DESCRIPTION

The classic characters from crypto and protocol
communications texts.

=head1 CONTRIBUTOR

Anonymous C<< <nobody@nowhere.org> >>. See ticket #9725 on
L<http://rt.cpan.org/>.

Introduced in version 0.04, published on January 15, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
alice bob charlie doris eve fred ginger harry irene janet 
