package Acme::MetaSyntactic::dilbert;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::dilbert - The Dilbert theme

=head1 DESCRIPTION

Characters from the Dilbert daily strip.

=head1 CONTRIBUTOR

Sébastien Aperghis-Tramoni.

Introduced in version 0.03, published on January 14, 2005.

Duplicate removed in version 0.15, published on March 28, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
dilbert dogbert catbert
ratbert bob dawn rex liz alice asok wally tina carol
mordac ted phil elbonia pointy_haired_boss
