package Acme::MetaSyntactic::toto;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::toto - The toto theme

=head1 DESCRIPTION

The traditional French metasyntactical names.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.01, published on January 14, 2005.

Updated by Jérôme Fenal in version 0.12, published on March 7, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>

=cut

__DATA__
# names
toto titi tata tutu pipo
bidon test1 test2 test3
