package Acme::MetaSyntactic::pynchon;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pynchon - The Pynchon theme

=head1 DESCRIPTION

Character names from Thomas Pynchon's books.

David Landgren not only named all the machines in the C<mongueurs.net>
domain (C<stencil>, C<sferics> and C<profane>) after characters from
Thomas Pynchon's books, but also provided a first list.

The pynchon list will probably grow in future versions, as David goes
through his books.

=head1 CONTRIBUTOR

David Landgren.

Introduced in version 0.03, published on January 14, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
porpentine slothrop stencil profane   godolphin  yoyodyne
waste      sferics  oedipa  mondaugen eigenvalue schlozhauer
schoenmaker bongo_shaftsbury maijstral achtfaden sachsa mantissa
