package Acme::MetaSyntactic::jamesbond;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::jamesbond - The James Bond theme

=head1 DESCRIPTION

The list of James Bond movies.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.07 (heh), published on January 31, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Die_Another_Day                 The_World_is_Not_Enough
Tomorrow_Never_Dies             GoldenEye             Licence_To_Kill
The_Living_Daylights            A_View_to_a_Kill      Octopussy           
For_Your_Eyes_Only              Moonraker             The_Spy_Who_Loved_Me 
The_Man_With_the_Golden_Gun     Live_and_Let_Die      Diamonds_Are_Forever  
On_Her_Majesty_s_Secret_Service You_Only_Live_Twice   Thunderball     
Goldfinger                      From_Russia_With_Love Dr_No
