package Acme::MetaSyntactic::hhgg;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::hhgg - The Hitch Hiker's Guide to the Galaxy theme

=head1 DESCRIPTION

Characters and other names from Douglas Adams's "Hitch Hiker's Guide to
the Galaxy" book series.

=head1 CONTRIBUTOR

Aldo Calpini.

Introduced in version 0.11, published on February 28, 2005.

Updated by Philippe "BooK" Bruhat in version 0.14, published on March 21, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
answer arthur babelfish beeblebrox bugblatter_beast eccentrica_gallumbits 
fenchurch ford heartofgold jeltz kwaltz magrathea marvin milliways 
pan_galactic_gargle_blaster slartibartfast trillian vogon wonko zaphod
fortytwo
